Method: Restforce::Concerns::API#recent

Defined in:
lib/restforce/concerns/api.rb

#recent(limit = nil) ⇒ Object

Public: Finds recently viewed items for the logged-in user.

limit - An optional limit that specifies the maximum number of records to be

returned.
If this parameter is not specified, the default maximum number of records
returned is the maximum number of entries in RecentlyViewed, which is 200
records per object.

Returns an array of the recently viewed Restforce::SObject records.



472
473
474
475
476
# File 'lib/restforce/concerns/api.rb', line 472

def recent(limit = nil)
  path = limit ? "recent?limit=#{limit}" : "recent"

  api_get(path).body
end