Method: Restforce::Collection#initialize
- Defined in:
- lib/restforce/collection.rb
#initialize(hash, client) ⇒ Collection
Given a hash and client, will create an Enumerator that will lazily request Salesforce for the next page of results.
7 8 9 10 |
# File 'lib/restforce/collection.rb', line 7 def initialize(hash, client) @client = client @raw_page = hash end |